@@ -144,7 +144,7 @@ async def status(ctx):
                             console.print(
                                 f"  Quota: {usage.get('tokens', 0)} / {quota}"
                             )
-                except:
+                except Exception:
                     console.print("[yellow]![/yellow] Credentials may be expired")
                     console.print("Run 'hanzo auth login' to refresh")
 
