@@ -167,7 +167,7 @@ hanzo> mcp run read_file --arg path=README.md
             async with httpx.AsyncClient() as client:
                 response = await client.get("http://localhost:8000/health", timeout=1.0)
                 return "running" if response.status_code == 200 else "not responding"
-        except:
+        except Exception:
             return "not running"
 
     async def count_agents(self) -> int:
